@@ -79,14 +79,23 @@ Plack::Middleware::AccessLog::Timed - Logs requests with time and accurate body
 =head1 DESCRIPTION
 
 Plack::Middleware::AccessLog::Timed is a subclass of
-Plack::Middleware::AccessLog but uses a wrapped body handle to get the
+L<Plack::Middleware::AccessLog> but uses a wrapped body handle to get the
 actual response body size C<%b> (even if it's not a chunk of array or
 a real filehandle) and the time taken to serve the request: C<%T> or
 C<%D>.
 
-This wraps the response body output stream so some server
-optimizations like sendfile(2) will be disabled if you use this
-middleware.
+This wraps the response body output stream to capture the time taken
+for the PSGI server to read the whole response body.
+
+This would mean, if the middlware is in use, it will prevent some
+server-side optimizations like sendfile(2) from working, as well as
+middleware like L<Plack::Middleware::ContentLength> can't guess the
+body size out of the file handle.
+
+If all you want is to capture the time taken in your PSGI application
+and do not want the wrapped body behavior described above, consider instead
+applying L<Plack::Middleware::Runtime> and using L<Plack::Middleware::AccessLog>
+to log the C<X-Runtime> header.
 
 =head1 CONFIGURATION
 
@@ -100,4 +109,6 @@ Tatsuhiko Miyagawa
 
 L<Plack::Middleware::AccessLog>
 
+L<Plack::Middleware::Runtime>
+
 =cut
